<p align="center">
<img src="https://images.squarespace-cdn.com/content/v1/57f6d51c9f74566f55ecf271/733ec9c2-52bc-4fcb-aefb-1516d0a50c19/amadeuslogo.png?format=1500w" width="95%">
</p>

🪄 **We turn natural language descriptions of behaviors into machine-executable code.**

- We use ChatGPT's API to bridge natural language and behavior analysis code.
- For more details, check out our arXiv preprint **AmadeusGPT: a natural language interface for interactive animal behavioral analysis** by [Shaokai Ye](https://github.com/yeshaokai), [Jessy Lauer](https://github.com/jeylau), [Mu Zhou](https://github.com/zhoumu53), [Alexander Mathis](https://github.com/AlexEMG) & [Mackenzie W. Mathis](https://github.com/MMathisLab).

- 🧙‍♀️ *Code coming soon!*

## Demo AmadeusGPT🎻

  - WIP [Click here]() to launch our hosted Streamlit App!
  - Please note you need an [openAPI key](https://platform.openai.com/account/api-keys), which you can easily create [here](https://platform.openai.com/account/api-keys).

## License 

  AmadeusGPT is license under the Apache-2.0 license.
  -  Please note several key dependencies have their own licensing. Please carefully check the license information for DeepLabCut (LGPL-3.0 license), SAM (Apache-2.0 license), CEBRA (Non-Commercial), etc...

## Citation

  If you use ideas or code from this project in your work, please cite us  using the following BibTeX entry. 🙏

 - AmadeusGPT

 ```
@article{ye2023amadeusGPT,
      title={AmadeusGPT: a natural language interface for interactive animal behavioral analysis}, 
      author={Shaokai Ye and Jessy Lauer and Mu Zhou and Alexander Mathis and Mackenzie Weygandt Mathis},
      journal={arXiv:WIP},
      year={2023}}
```

## Questions?

- [Contact us](http://www.mackenziemathislab.org/)
